@@ -96,34 +96,27 @@ view_df <- function(x,
                     use.viewer = TRUE,
                     no.output = FALSE,
                     remove.spaces = TRUE) {
-# -------------------------------------
   # check encoding
-  # -------------------------------------
   encoding <- get.encoding(encoding, x)
-  # -------------------------------------
+  
   # make data frame of single variable, so we have
   # unique handling for the data
-  # -------------------------------------
   if (!is.data.frame(x)) stop("Parameter needs to be a data frame!", call. = FALSE)
-  # -------------------------------------
+  
   # retrieve value and variable labels
-  # -------------------------------------
   df.var <- sjmisc::get_label(x)
   df.val <- sjmisc::get_labels(x)
-  # -------------------------------------
+  
   # get row count and ID's
-  # -------------------------------------
   colcnt <- ncol(x)
   id <- seq_len(colcnt)
-  # -------------------------------------
+  
   # Order data set if requested
-  # -------------------------------------
   if (sort.by.name) id <- id[order(colnames(x))]
-  # -------------------------------------
+
   # init style sheet and tags used for css-definitions
   # we can use these variables for string-replacement
   # later for return value
-  # -------------------------------------
   tag.table <- "table"
   tag.thead <- "thead"
   tag.tdata <- "tdata"
@@ -134,9 +127,8 @@ view_df <- function(x,
   css.tdata <- "padding:0.2cm; text-align:left; vertical-align:top;"
   css.arc <- "background-color:#eaeaea"
   css.caption <- "font-weight: bold; text-align:left;"
-  # ------------------------
+  
   # check user defined style sheets
-  # ------------------------
   if (!is.null(CSS)) {
     if (!is.null(CSS[['css.table']])) css.table <- ifelse(substring(CSS[['css.table']], 1, 1) == '+', paste0(css.table, substring(CSS[['css.table']], 2)), CSS[['css.table']])
     if (!is.null(CSS[['css.thead']])) css.thead <- ifelse(substring(CSS[['css.thead']], 1, 1) == '+', paste0(css.thead, substring(CSS[['css.thead']], 2)), CSS[['css.thead']])
@@ -144,23 +136,19 @@ view_df <- function(x,
     if (!is.null(CSS[['css.arc']])) css.arc <- ifelse(substring(CSS[['css.arc']], 1, 1) == '+', paste0(css.arc, substring(CSS[['css.arc']], 2)), CSS[['css.arc']])
     if (!is.null(CSS[['css.caption']])) css.caption <- ifelse(substring(CSS[['css.caption']], 1, 1) == '+', paste0(css.caption, substring(CSS[['css.caption']], 2)), CSS[['css.caption']])
   }
-  # -------------------------------------
+  
   # set style sheet
-  # -------------------------------------
   page.style <- sprintf("<style>\n%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n%s { %s }\n</style>",
                         tag.table, css.table, tag.thead, css.thead, tag.tdata, css.tdata,
                         tag.arc, css.arc, tag.caption, css.caption)
-  # -------------------------------------
+  
   # table init
-  # -------------------------------------
   toWrite <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n%s\n</head>\n<body>\n", encoding, page.style)
-  # -------------------------------------
+  
   # table caption, data frame name
-  # -------------------------------------
   page.content <- sprintf("<table>\n  <caption>Data frame: %s</caption>\n", deparse(substitute(x)))
-  # -------------------------------------
+  
   # header row
-  # -------------------------------------
   page.content <- paste0(page.content, "  <tr>\n    ")
   if (show.id) page.content <- paste0(page.content, "<th class=\"thead\">ID</th>")
   page.content <- paste0(page.content, "<th class=\"thead\">Name</th>")
@@ -174,36 +162,50 @@ view_df <- function(x,
   if (show.wtd.frq) page.content <- paste0(page.content, "<th class=\"thead\">weighted Freq.</th>")
   if (show.wtd.prc) page.content <- paste0(page.content, "<th class=\"thead\">weighted %</th>")
   page.content <- paste0(page.content, "\n  </tr>\n")
-  # -------------------------------------
+  
   # create progress bar
-  # -------------------------------------
   if (!hide.progress) pb <- utils::txtProgressBar(min = 0, max = colcnt, style = 3)
-  # -------------------------------------
+  
   # subsequent rows
-  # -------------------------------------
   for (ccnt in seq_len(colcnt)) {
     # get index number, depending on sorting
     index <- id[ccnt]
     # default row string
     arcstring <- ""
+    
     # if we have alternating row colors, set css
     if (altr.row.col) arcstring <- ifelse(sjmisc::is_even(ccnt), " arc", "")
     page.content <- paste0(page.content, "  <tr>\n")
+    
     # ID
-    if (show.id) page.content <- paste0(page.content, sprintf("    <td class=\"tdata%s\">%i</td>\n", arcstring, index))
+    if (show.id)
+      page.content <-
+      paste0(page.content,
+             sprintf("    <td class=\"tdata%s\">%i</td>\n", arcstring, index))
+    
     # name, and note
     if (!is.null(sjmisc::get_note(x[[index]])))
       td.title.tag <- sprintf(" title=\"%s\"", sjmisc::get_note(x[[index]]))
     else
       td.title.tag <- ""
-    page.content <- paste0(page.content, sprintf("    <td class=\"tdata%s\"%s>%s</td>\n", arcstring, td.title.tag, colnames(x)[index]))
+    
+    page.content <-
+      paste0(
+        page.content,
+        sprintf(
+          "    <td class=\"tdata%s\"%s>%s</td>\n",
+          arcstring,
+          td.title.tag,
+          colnames(x)[index]
+        )
+      )
+    
     # type
     if (show.type) {
       vartype <- get.vartype(x[[index]])
-      page.content <- paste0(page.content,
-                             sprintf("    <td class=\"tdata%s\">%s</td>\n",
-                                     arcstring,
-                                     vartype))
+      page.content <-
+        paste0(page.content,
+               sprintf("    <td class=\"tdata%s\">%s</td>\n", arcstring, vartype))
     }
     # label
     if (index <= length(df.var)) {
@@ -216,19 +218,21 @@ view_df <- function(x,
       varlab <- "<NA>"
     }
     page.content <- paste0(page.content, sprintf("    <td class=\"tdata%s\">%s</td>\n", arcstring, varlab))
-    # ----------------------------
+    
     # missings and missing percentage
-    # ----------------------------
     if (show.na) {
-      page.content <- paste0(page.content,
-                             sprintf("    <td class=\"tdata%s\">%i (%.2f%%)</td>\n",
-                                     arcstring,
-                                     sum(is.na(x[[index]]), na.rm = T),
-                                     100 * sum(is.na(x[[index]]), na.rm = T) / nrow(x)))
+      page.content <- paste0(
+        page.content,
+        sprintf(
+          "    <td class=\"tdata%s\">%i (%.2f%%)</td>\n",
+          arcstring,
+          sum(is.na(x[[index]]), na.rm = T),
+          100 * sum(is.na(x[[index]]), na.rm = T) / nrow(x)
+        )
+      )
     }
-    # ----------------------------
+
     # values
-    # ----------------------------
     if (show.values) {
       valstring <- ""
       # do we have valid index?
@@ -238,7 +242,7 @@ view_df <- function(x,
         # check if we have any values...
         if (!is.null(vals)) {
           # if we have values, put all values into a string
-          for (i in 1:length(vals)) {
+          for (i in seq_len(length(vals))) {
             valstring <- paste0(valstring, vals[i])
             if (i < length(vals)) valstring <- paste0(valstring, "<br>")
           }
@@ -246,11 +250,12 @@ view_df <- function(x,
       } else {
         valstring <- "<NA>"
       }
-      page.content <- paste0(page.content, sprintf("    <td class=\"tdata%s\">%s</td>\n", arcstring, valstring))
+      page.content <-
+        paste0(page.content,
+               sprintf("    <td class=\"tdata%s\">%s</td>\n", arcstring, valstring))
     }
-    # ----------------------------
+    
     # value labels
-    # ----------------------------
     if (show.labels) {
       valstring <- ""
       # do we have valid index?
@@ -262,7 +267,7 @@ view_df <- function(x,
         # check if we have any values...
         if (!is.null(vals)) {
           # if yes, add all to a string
-          for (i in 1:length(vals)) {
+          for (i in seq_len(length(vals))) {
             valstring <- paste0(valstring, vals[i])
             if (i < length(vals)) valstring <- paste0(valstring, "<br>")
           }
@@ -272,91 +277,95 @@ view_df <- function(x,
       }
       page.content <- paste0(page.content, sprintf("    <td class=\"tdata%s\">%s</td>\n", arcstring, valstring))
     }
-    # ----------------------------
+    
     # frequencies
-    # ----------------------------
     if (show.frq) {
-      page.content <- paste0(page.content,
-                             sprintf("    <td class=\"tdata%s\">%s</td>\n",
-                                     arcstring,
-                                     frq.value(index, x, df.val)))
+      page.content <-
+        paste0(page.content,
+               sprintf(
+                 "    <td class=\"tdata%s\">%s</td>\n",
+                 arcstring,
+                 frq.value(index, x, df.val)
+               ))
     }
-    # ----------------------------
+    
     # percentage of frequencies
-    # ----------------------------
     if (show.prc) {
-      page.content <- paste0(page.content,
-                             sprintf("    <td class=\"tdata%s\">%s</td>\n",
-                                     arcstring,
-                                     prc.value(index, x, df.val)))
+      page.content <-
+        paste0(page.content,
+               sprintf(
+                 "    <td class=\"tdata%s\">%s</td>\n",
+                 arcstring,
+                 prc.value(index, x, df.val)
+               ))
     }
-    # ----------------------------
+    
     # frequencies
-    # ----------------------------
     if (show.wtd.frq && !is.null(weight.by)) {
-      page.content <- paste0(page.content,
-                             sprintf("    <td class=\"tdata%s\">%s</td>\n",
-                                     arcstring,
-                                     frq.value(index, x, df.val, weight.by)))
+      page.content <-
+        paste0(page.content,
+               sprintf(
+                 "    <td class=\"tdata%s\">%s</td>\n",
+                 arcstring,
+                 frq.value(index, x, df.val, weight.by)
+               ))
     }
-    # ----------------------------
+    
     # percentage of frequencies
-    # ----------------------------
     if (show.prc && !is.null(weight.by)) {
-      page.content <- paste0(page.content,
-                             sprintf("    <td class=\"tdata%s\">%s</td>\n",
-                                     arcstring,
-                                     prc.value(index, x, df.val, weight.by)))
+      page.content <-
+        paste0(page.content,
+               sprintf(
+                 "    <td class=\"tdata%s\">%s</td>\n",
+                 arcstring,
+                 prc.value(index, x, df.val, weight.by)
+               ))
     }
+    
     # update progress bar
     if (!hide.progress) utils::setTxtProgressBar(pb, ccnt)
     # close row tag
     page.content <- paste0(page.content, "  </tr>\n")
   }
   if (!hide.progress) close(pb)
-  # -------------------------------------
+  
   # finish html page
-  # -------------------------------------
   page.content <- paste(page.content, "</table>", sep = "\n")
   toWrite <- paste0(toWrite, sprintf("%s\n</body></html>", page.content))
-  # -------------------------------------
+  
   # replace class attributes with inline style,
   # useful for knitr
-  # -------------------------------------
-  # copy page content
-  # -------------------------------------
   knitr <- page.content
-  # -------------------------------------
+  
   # set style attributes for main table tags
-  # -------------------------------------
   knitr <- gsub("class=", "style=", knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub("<table", sprintf("<table style=\"%s\"", css.table), knitr, fixed = TRUE, useBytes = TRUE)
-  # -------------------------------------
+  
   # replace class-attributes with inline-style-definitions
-  # -------------------------------------
   knitr <- gsub(tag.tdata, css.tdata, knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub(tag.thead, css.thead, knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub(tag.arc, css.arc, knitr, fixed = TRUE, useBytes = TRUE)
-  # -------------------------------------
+  
   # remove spaces?
-  # -------------------------------------
   if (remove.spaces) {
     knitr <- sju.rmspc(knitr)
     toWrite <- sju.rmspc(toWrite)
     page.content <- sju.rmspc(page.content)
   }
-  # -------------------------------------
+  
   # check if html-content should be outputted
-  # -------------------------------------
   out.html.table(no.output, file, knitr, toWrite, use.viewer)
-  # -------------------------------------
+  
   # return results
-  # -------------------------------------
-  invisible(structure(class = c("sjTable", "view_df"),
-                      list(page.style = page.style,
-                           page.content = page.content,
-                           output.complete = toWrite,
-                           knitr = knitr)))
+  invisible(structure(
+    class = c("sjTable", "view_df"),
+    list(
+      page.style = page.style,
+      page.content = page.content,
+      output.complete = toWrite,
+      knitr = knitr
+    )
+  ))
 }
 
 
